# aliseeks_api

AliseeksApi - the Ruby gem for the Aliseeks API

AliExpress product searching and product details retrieval API.


This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.4
- Build package: org.openapitools.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build aliseeks_api.gemspec
```

Then either install the gem locally:

```shell
gem install ./aliseeks_api-1.0.4.gem
```
(for development, run `gem install --dev ./aliseeks_api-1.0.4.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'aliseeks_api', '~> 1.0.4'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/aliseeks/connect-ruby-sdk, then add the following in the Gemfile:

    gem 'aliseeks_api', :git => 'https://github.com/aliseeks/connect-ruby-sdk.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'aliseeks_api'

# Setup authorization
AliseeksApi.configure do |config|
  # Configure API key authorization: ApiKeyAuth
  config.api_key['X-API-CLIENT-ID'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-API-CLIENT-ID'] = 'Bearer'
end

api_instance = AliseeksApi::ProductsApi.new
opts = {
  product_request: AliseeksApi::ProductRequest.new # ProductRequest | The request body of get product 
}

begin
  #Get products details as an aggregated request from AliExpress in realtime. 
  result = api_instance.get_product(opts)
  p result
rescue AliseeksApi::ApiError => e
  puts "Exception when calling ProductsApi->get_product: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.aliseeks.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AliseeksApi::ProductsApi* | [**get_product**](docs/ProductsApi.md#get_product) | **POST** /products | Get products details as an aggregated request from AliExpress in realtime. 
*AliseeksApi::ProductsApi* | [**get_product_details**](docs/ProductsApi.md#get_product_details) | **POST** /products/details | Gets product details from AliExpress in realtime. 
*AliseeksApi::ProductsApi* | [**get_product_html_description**](docs/ProductsApi.md#get_product_html_description) | **POST** /products/description/html | Get product HTML description from AliExpress in realtime. 
*AliseeksApi::ProductsApi* | [**get_product_reviews**](docs/ProductsApi.md#get_product_reviews) | **POST** /products/reviews | Get product reviews from AliExpress in realtime 
*AliseeksApi::ProductsApi* | [**get_product_shipping**](docs/ProductsApi.md#get_product_shipping) | **POST** /products/shipping | Gets product shipping information AliExpress in realtime. 
*AliseeksApi::ProductsApi* | [**get_product_skus**](docs/ProductsApi.md#get_product_skus) | **POST** /products/variations | Gets product skus / variation information from AliExpress in realtime. 
*AliseeksApi::SearchApi* | [**realtime_search**](docs/SearchApi.md#realtime_search) | **POST** /search/realtime | Searches AliExpress in realtime 
*AliseeksApi::SearchApi* | [**search**](docs/SearchApi.md#search) | **POST** /search | Searches AliExpress in non-realtime. Uses the Aliseeks.com datasource which is continually updated from AliExpress. 
*AliseeksApi::SearchApi* | [**search_best_selling**](docs/SearchApi.md#search_best_selling) | **POST** /search/bestSelling | Retrieves best selling products from AliExpress in realtime. 
*AliseeksApi::SearchApi* | [**search_by_image**](docs/SearchApi.md#search_by_image) | **POST** /search/image | Searches AliExpress by image in realtime. 
*AliseeksApi::SearchApi* | [**upload_image_by_url**](docs/SearchApi.md#upload_image_by_url) | **POST** /search/image/upload | Uploads an image to AliExpress to allow it to be used in the image search endpoint 


## Documentation for Models

 - [AliseeksApi::Amount](docs/Amount.md)
 - [AliseeksApi::BestSellingSearchItem](docs/BestSellingSearchItem.md)
 - [AliseeksApi::BestSellingSearchRequest](docs/BestSellingSearchRequest.md)
 - [AliseeksApi::BestSellingSearchResponse](docs/BestSellingSearchResponse.md)
 - [AliseeksApi::DoubleRange](docs/DoubleRange.md)
 - [AliseeksApi::ImageSearchCategory](docs/ImageSearchCategory.md)
 - [AliseeksApi::ImageSearchItem](docs/ImageSearchItem.md)
 - [AliseeksApi::ImageSearchRequest](docs/ImageSearchRequest.md)
 - [AliseeksApi::ImageSearchResponse](docs/ImageSearchResponse.md)
 - [AliseeksApi::IntegerRange](docs/IntegerRange.md)
 - [AliseeksApi::NonRealtimeCurrency](docs/NonRealtimeCurrency.md)
 - [AliseeksApi::PriceRange](docs/PriceRange.md)
 - [AliseeksApi::PriceSummary](docs/PriceSummary.md)
 - [AliseeksApi::Product](docs/Product.md)
 - [AliseeksApi::ProductAttribute](docs/ProductAttribute.md)
 - [AliseeksApi::ProductBulkOption](docs/ProductBulkOption.md)
 - [AliseeksApi::ProductDetail](docs/ProductDetail.md)
 - [AliseeksApi::ProductDetailsRequest](docs/ProductDetailsRequest.md)
 - [AliseeksApi::ProductHtmlDescription](docs/ProductHtmlDescription.md)
 - [AliseeksApi::ProductHtmlDescriptionRequest](docs/ProductHtmlDescriptionRequest.md)
 - [AliseeksApi::ProductPriceOption](docs/ProductPriceOption.md)
 - [AliseeksApi::ProductPromotion](docs/ProductPromotion.md)
 - [AliseeksApi::ProductPropertyVariationIdentifier](docs/ProductPropertyVariationIdentifier.md)
 - [AliseeksApi::ProductRequest](docs/ProductRequest.md)
 - [AliseeksApi::ProductRequestComponent](docs/ProductRequestComponent.md)
 - [AliseeksApi::ProductReview](docs/ProductReview.md)
 - [AliseeksApi::ProductReviews](docs/ProductReviews.md)
 - [AliseeksApi::ProductReviewsRequest](docs/ProductReviewsRequest.md)
 - [AliseeksApi::ProductSeller](docs/ProductSeller.md)
 - [AliseeksApi::ProductShipping](docs/ProductShipping.md)
 - [AliseeksApi::ProductShippingOptions](docs/ProductShippingOptions.md)
 - [AliseeksApi::ProductShippingRequest](docs/ProductShippingRequest.md)
 - [AliseeksApi::ProductSku](docs/ProductSku.md)
 - [AliseeksApi::ProductSkus](docs/ProductSkus.md)
 - [AliseeksApi::ProductSkusRequest](docs/ProductSkusRequest.md)
 - [AliseeksApi::PromotionOption](docs/PromotionOption.md)
 - [AliseeksApi::RealtimeCurrency](docs/RealtimeCurrency.md)
 - [AliseeksApi::RealtimeSearchAggregation](docs/RealtimeSearchAggregation.md)
 - [AliseeksApi::RealtimeSearchItem](docs/RealtimeSearchItem.md)
 - [AliseeksApi::RealtimeSearchRequest](docs/RealtimeSearchRequest.md)
 - [AliseeksApi::RealtimeSearchResponse](docs/RealtimeSearchResponse.md)
 - [AliseeksApi::SearchAggregation](docs/SearchAggregation.md)
 - [AliseeksApi::SearchItem](docs/SearchItem.md)
 - [AliseeksApi::SearchItemFreight](docs/SearchItemFreight.md)
 - [AliseeksApi::SearchItemFreightType](docs/SearchItemFreightType.md)
 - [AliseeksApi::SearchItemSeller](docs/SearchItemSeller.md)
 - [AliseeksApi::SearchPriceOption](docs/SearchPriceOption.md)
 - [AliseeksApi::SearchRequest](docs/SearchRequest.md)
 - [AliseeksApi::SearchResponse](docs/SearchResponse.md)
 - [AliseeksApi::SkuPriceOption](docs/SkuPriceOption.md)
 - [AliseeksApi::SkuPriceOptionProperty](docs/SkuPriceOptionProperty.md)
 - [AliseeksApi::SkuProperty](docs/SkuProperty.md)
 - [AliseeksApi::SkuPropertyValue](docs/SkuPropertyValue.md)
 - [AliseeksApi::StringRange](docs/StringRange.md)
 - [AliseeksApi::TimeDuration](docs/TimeDuration.md)
 - [AliseeksApi::TradeInformation](docs/TradeInformation.md)
 - [AliseeksApi::UploadImageByUrlRequest](docs/UploadImageByUrlRequest.md)
 - [AliseeksApi::UploadImageResponse](docs/UploadImageResponse.md)
 - [AliseeksApi::WebError](docs/WebError.md)


## Documentation for Authorization


### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-CLIENT-ID
- **Location**: HTTP header

